@@ -8,12 +8,40 @@ __status__ = "Production"
 import numpy as np
 from scipy import constants
 from scipy.optimize import brentq
-from .particles import Atom, MoleculeMultiT, MoleculeQuasi, MoleculeOneT
+from .particles import Atom, MoleculeMultiT, MoleculeQuasi, MoleculeOneT, Molecule
 from .errors import KineticlibError
 from math import exp
 
 
-def Gamma_VT(T: float, T1: float, molecule: MoleculeMultiT, delta: int) -> float:
+def Gamma_vt_sts(T: float, molecule: Molecule, i: int, delta: int, ni_before: float, ni_after: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
+    **M(i) + P -> M(i+delta) + P** in the state-to-state approximation
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule : Molecule
+        the molecule undergoing the transition
+    i : int
+        the vibrational level of the molecule before the transition
+    delta : int
+        the change in vibrational level of the molecule undergoing the transition
+    ni_before : float
+        the numeric density of molecules of species M at the original vibrationa level (before the transition)
+    ni_after : float
+        the numeric density of molecules of species M at the new vibrational level (after the transition)
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a VT transition
+
+    """
+    return raw_Gamma_vt_sts(T, molecule.vibr[i], molecule.vibr[i + delta], ni_before, ni_after)
+
+
+def Gamma_vt(T: float, T1: float, molecule: MoleculeMultiT, delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
     **M(i) + P -> M(i+delta) + P** in the multi-temperature approximation
 
@@ -34,10 +62,51 @@ def Gamma_VT(T: float, T1: float, molecule: MoleculeMultiT, delta: int) -> float
         The generalized thermodynamic force for a VT transition
 
     """
-    return raw_Gamma_VT(T, T1, molecule.vibr[1], delta)
+    return raw_Gamma_vt(T, T1, molecule.vibr[1], delta)
 
 
-def Gamma_VV(T: float, T1_1: float, T1_2: float, molecule1: MoleculeMultiT, molecule2: MoleculeMultiT, i_delta: int,
+def Gamma_vv_sts(T: float, molecule1: Molecule, molecule2: Molecule, i: int, k: int, i_delta: int,
+                 k_delta: int, ni_before1: float, ni_before2: float, ni_afer1: float, ni_afer2: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
+    **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the state-to-state approximation
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule1 : Molecule
+        the molecule M1
+    molecule2 : Molecule
+        the molecule M2
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_delta : int
+        the change in vibrational level of molecule M1
+    k_delta : int
+        the change in vibrational level of molecule M2
+    ni_before1 : float
+        the numeric density of molecules of species M1 at the original vibrationa level (before the transition)
+    ni_before2 : float
+        the numeric density of molecules of species M2 at the original vibrationa level (before the transition)
+    ni_after1 : float
+        the numeric density of molecules of species M1 at the new vibrational level (after the transition)
+    ni_after2 : float
+        the numeric density of molecules of species M2 at the new vibrational level (after the transition)
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a VV transition
+
+    """
+    return raw_Gamma_vv_sts(T, molecule1.vibr[i], molecule2.vibr[k],
+                            molecule1.vibr[i + i_delta], molecule2.vibr[k + k_delta],
+                            ni_before1, ni_before2, ni_afer1, ni_afer2)
+
+
+def Gamma_vv(T: float, T1_1: float, T1_2: float, molecule1: MoleculeMultiT, molecule2: MoleculeMultiT, i_delta: int,
              k_delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
     **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the multi-temperature approximation
@@ -65,7 +134,57 @@ def Gamma_VV(T: float, T1_1: float, T1_2: float, molecule1: MoleculeMultiT, mole
         The generalized thermodynamic force for a VV transition
 
     """
-    return raw_Gamma_VV(T, T1_1, T1_2, molecule1.vibr[1], molecule2.vibr[1], i_delta, k_delta)
+    return raw_Gamma_vv(T, T1_1, T1_2, molecule1.vibr[1], molecule2.vibr[1], i_delta, k_delta)
+
+
+def Gamma_22_sts(T: float, molecule1: Molecule, molecule2: Molecule, molecule_new1: Molecule, molecule_new2: Molecule,
+                 n_molecule1: float, n_molecule2: float, n_molecule_new1: float, n_molecule_new2: float,
+                 i: int, k: int, i_new: int, k_new: int) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\\rightleftarrows2}` for a bimolecular
+    exchange reaction in the state-to-state approximation:
+    **M1(i) + M2(k) -> M3(i_new) + M4(k_new)**
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule1 : Molecule
+        the molecule M1
+    molecule2 : Molecule
+        the molecule M2
+    molecule_new1 : Molecule
+        the molecule M3
+    molecule_new2 : Molecule
+        the molecule M4
+    i : int
+        the vibrational level of molecule M1
+    k : int
+        the vibrational level of molecule M2
+    i_new : int
+        the vibrational level of molecule M3
+    k_new : int
+        the vibrational level of molecule M4
+    n_molecule1 : float
+        the numeric density of molecules of species M1 at the vibrationa level i
+    n_molecule2 : float
+        the numeric density of molecules of species M2 at the vibrationa level k
+    n_molecule_new1 : float
+        the numeric density of molecules of species M3 at the vibrationa level i_new
+    n_molecule_new2 : float
+        the numeric density of molecules of species M4 at the vibrationa level k_new
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a bimolecular chemical exchange reaction
+
+    """
+    return raw_Gamma_22_sts(T, molecule1.vibr[i], molecule2.vibr[k],
+                            molecule_new1.vibr[i_new], molecule_new2.vibr[k_new],
+                            molecule1.Z_rot(T), molecule2.Z_rot(T), molecule_new1.Z_rot(T), molecule_new2.Z_rot(T),
+                            molecule1.mass, molecule2.mass, molecule_new1.mass, molecule_new2.mass,
+                            molecule1.form, molecule2.form, molecule_new1.form, molecule_new2.form,
+                            n_molecule1, n_molecule2, n_molecule_new1, n_molecule_new2)
 
 
 def Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float, molecule1: MoleculeQuasi,
@@ -148,6 +267,40 @@ def Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float,
         raise KineticlibError('Types of molecules do not match!')
 
 
+def Gamma_diss_sts(T: float, molecule: Molecule, atom1: Atom, atom2: Atom,
+                   n_molecule: float, n_atom1: float, n_atom2: float, diss_level: int) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{diss}` for a dissociation reaction:
+    **AB(diss_level) + P -> A + B + P** in the state-to-state approximation
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule : Molecule
+        the molecule which dissociates
+    atom1 : Atom
+        atom of the first atomic species which make up the molecule
+    atom2 : Atom
+        atom of the second atomic species which make up the molecule
+    n_molecule : float
+        the numeric density of molecules of species M at the vibrational level diss_level
+    n_atom1 : float
+        the numeric density of atoms of species atom1
+    n_atom2 : float
+        the numeric density of atoms of species atom2
+    diss_level : int
+        the vibrational level from which the molecule dissociates
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a dissociation reaction
+
+    """
+    return raw_Gamma_diss_sts(T, molecule.vibr[diss_level], molecule.Z_rot(T), molecule.mass, atom1.mass,
+                              atom2.mass, molecule.diss, n_molecule, n_atom1, n_atom2)
+
+
 def Gamma_diss(T: float, T1: float, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom, n_molecule: float,
                n_atom1: float, n_atom2: float, diss_level: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{diss}` for a dissociation reaction:
@@ -217,7 +370,33 @@ def find_natom_diss_eq(T: float, molecule: MoleculeOneT, atom: Atom, n: float, r
     return raw_find_natom_diss_eq(T, molecule.Z_int(T), molecule.mass, atom.mass, molecule.diss, n, relative)
 
 
-def raw_Gamma_VT(T: float, T1: float, vibr_one: float, delta: int) -> float:
+def raw_Gamma_vt_sts(T: float, ve_before: float, ve_after: float, ni_before: float, ni_afer: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
+    **M(i) + P -> M(i+delta) + P** in the state-to-state approximation, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    ve_before : float
+        the vibrational energy of the molecule before the transition
+    ve_after : float
+        the vibrational energy of the molecule after the transition
+    ni_before : float
+        the numeric density of molecules of species M at the original vibrationa level (before the transition)
+    ni_after : float
+        the numeric density of molecules of species M at the new vibrational level (after the transition)
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a VT transition
+
+    """
+    return 1.0 - ni_afer * exp((ve_after - ve_before) / (constants.k * T)) / ni_before
+
+
+def raw_Gamma_vt(T: float, T1: float, vibr_one: float, delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VT}` for a VT transition:
     **M(i) + P -> M(i+delta) + P** in the multi-temperature approximation, *raw* version
 
@@ -241,7 +420,43 @@ def raw_Gamma_VT(T: float, T1: float, vibr_one: float, delta: int) -> float:
     return 1.0 - exp((vibr_one * delta * (1.0 / T - 1.0 / T1)) / constants.k)
 
 
-def raw_Gamma_VV(T: float, T1_1: float, T1_2: float, vibr_one1: float, vibr_one2: float,
+def raw_Gamma_vv_sts(T: float, ve_before1: float, ve_before2: float, ve_after1: float, ve_after2: float,
+                     ni_before1: float, ni_before2: float, ni_afer1: float, ni_afer2: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
+    **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the state-to-state approximation, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    ve_before1 : float
+        the vibrational energy of the molecule M1 before the transition
+    ve_before2 : float
+        the vibrational energy of the molecule M2 before the transition
+    ve_after1 : float
+        the vibrational energy of the molecule M1 after the transition
+    ve_after2 : float
+        the vibrational energy of the molecule M2 after the transition
+    ni_before1 : float
+        the numeric density of molecules of species M1 at the original vibrationa level (before the transition)
+    ni_before2 : float
+        the numeric density of molecules of species M2 at the original vibrationa level (before the transition)
+    ni_after1 : float
+        the numeric density of molecules of species M1 at the new vibrational level (after the transition)
+    ni_after2 : float
+        the numeric density of molecules of species M2 at the new vibrational level (after the transition)
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a VV transition
+
+    """
+    return 1.0 - ni_afer1 * ni_afer2 * exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / (constants.k * T))\
+                 / (ni_before1 * ni_before2)
+
+
+def raw_Gamma_vv(T: float, T1_1: float, T1_2: float, vibr_one1: float, vibr_one2: float,
                  i_delta: int, k_delta: int) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{VV}` for a VV transition:
     **M1(i) + M2(k) -> M1(i+i_delta) + M2(k+k_delta)** in the multi-temperature approximation, *raw* version
@@ -273,6 +488,76 @@ def raw_Gamma_VV(T: float, T1_1: float, T1_2: float, vibr_one1: float, vibr_one2
     return 1.0 - exp(add / (constants.k * T))
 
 
+def raw_Gamma_22_sts(T: float, ve_before1: float, ve_before2: float, ve_after1: float, ve_after2: float,
+                     Z_rot1: float, Z_rot2: float, Z_rot_new1: float, Z_rot_new2: float,
+                     mass1: float, mass2: float, mass_new1: float, mass_new2: float,
+                     form1: float, form2: float, form_new1: float, form_new2: float,
+                     n_molecule1: float, n_molecule2: float, n_molecule_new1: float, n_molecule_new2: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{2\\rightleftarrows2}` for a bimolecular
+    exchange reaction in the state-to-state approximation:
+    **M1(i) + M2(k) -> M3(i_new) + M4(k_new)**, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    ve_before1 : float
+        the vibrational energy of the molecule M1
+    ve_before2 : float
+        the vibrational energy of the molecule M2
+    ve_after1 : float
+        the vibrational energy of the molecule M3
+    ve_after2 : float
+        the vibrational energy of the molecule M4
+    Z_rot1 : float
+        the value of the rotational partition function of the molecule M1
+    Z_rot2 : float
+        the value of the rotational partition function of the molecule M2
+    Z_rot_new1 : float
+        the value of the rotational partition function of the molecule M3
+    Z_rot_new2 : float
+        the value of the rotational partition function of the molecule M4
+    mass1 : float
+        the mass of the molecule M1
+    mass2 : float
+        the mass of the molecule M2
+    mass_new1 : float
+        the mass of the molecule M3
+    mass_new2 : float
+        the mass of the molecule M4
+    form1 : float
+        the formation energy of the molecule M1
+    form2 : float
+        the formation energy of the molecule M2
+    form_new1 : float
+        the formation energy of the molecule M3
+    form_new2 : float
+        the formation energy of the molecule M4
+    n_molecule1 : float
+        the numeric density of molecules of species M1 at the vibrationa level i
+    n_molecule2 : float
+        the numeric density of molecules of species M2 at the vibrationa level k
+    n_molecule_new1 : float
+        the numeric density of molecules of species M3 at the vibrationa level i_new
+    n_molecule_new2 : float
+        the numeric density of molecules of species M4 at the vibrationa level k_new
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a bimolecular chemical exchange reaction
+
+    """
+    kT = constants.k * T
+    add = Z_rot1 * Z_rot2 / (Z_rot_new1 * Z_rot_new2)
+    add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
+    add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
+    add *= np.exp((form_new1 + form_new2 - form1 - form2) / kT)
+    add *= np.exp((ve_after1 + ve_after2 - ve_before1 - ve_before2) / kT)
+
+    return 1.0 - add
+
+
 def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: float,
                  vibr_zero1: float, vibr_zero2: float, vibr_zero_new1: float, vibr_zero_new2: float,
                  vibr_one1: float, vibr_one2: float,
@@ -361,10 +646,10 @@ def raw_Gamma_22(T: float, T1_1: float, T1_2: float, T1_new1: float, T1_new2: fl
     """
     kT = constants.k * T
     add = Z_int1 * Z_int2 / (Z_int_new1 * Z_int_new2)
-    add *= (n_molecule1 * n_molecule2) / (n_molecule_new1 * n_molecule_new2)
+    add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
-    add *= np.exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT + vibr_zero_new1 / kT + vibr_zero_new2 / kT
-                  - vibr_zero1 / kT - vibr_zero2 / kT)
+    add *= np.exp((form_new1 + form_new2 - form1 - form2 + vibr_zero_new1 + vibr_zero_new2
+                  - vibr_zero1 - vibr_zero2) / kT)
     add *= np.exp(vibr_one1 * i * (1.0 / (constants.k * T1_1) - 1.0 / kT)
                   + vibr_one2 * k * (1.0 / (constants.k * T1_2) - 1.0 / kT)
                   - vibr_one_new1 * i_new * (1.0 / (constants.k * T1_new1) - 1.0 / kT)
@@ -425,12 +710,52 @@ def raw_Gamma_22_oneT(T: float, Z_int1: float, Z_int2: float, Z_int_new1: float,
     """
     kT = constants.k * T
     add = Z_int1 * Z_int2 / (Z_int_new1 * Z_int_new2)
-    add *= (n_molecule1 * n_molecule2) / (n_molecule_new1 * n_molecule_new2)
+    add *= (n_molecule_new1 * n_molecule_new2) / (n_molecule1 * n_molecule2)
     add *= (mass1 * mass2 / (mass_new1 * mass_new2)) ** 1.5
     add *= np.exp(form_new1 / kT + form_new2 / kT - form1 / kT - form2 / kT)
     return 1.0 - add
 
 
+def raw_Gamma_diss_sts(T: float, molecule_vibr: float,
+                       Z_rot: float, mass_molecule: float, mass_atom1: float, mass_atom2: float,
+                       molecule_diss: float, n_molecule: float, n_atom1: float, n_atom2: float) -> float:
+    """Calculates the generalized thermodynamic force :math:`\\Gamma^{diss}` for a dissociation reaction:
+    **AB(diss_level) + P -> A + B + P** in the state-to-state approximation, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    Z_rot : float
+        the value of the rotational partition function of the molecule which dissociates
+    mass_molecule : float
+        the mass of the molecule which dissociates
+    mass_atom1 : float
+        the mass of the first atom product of dissociation
+    mass_atom2 : float
+        the mass of the second atom product of dissociation
+    molecule_diss : float
+        the dissociation energy of the molecule which dissociates (with no offset)
+    n_molecule : float
+        the numeric density of molecules of species M at the vibrational level diss_level
+    n_atom1 : float
+        the numeric density of atoms of species atom1
+    n_atom2 : float
+        the numeric density of atoms of species atom2
+
+    Returns
+    -------
+    float
+        The generalized thermodynamic force for a dissociation reaction
+
+    """
+    add = Z_rot * (n_atom1 * n_atom2) * (constants.h ** 3)\
+                                      * ((mass_molecule / (2.0 * mass_atom1 * mass_atom2 * constants.pi
+                                                               * constants.k * T)) ** 1.5) / n_molecule
+    add *= exp((molecule_diss - molecule_vibr) / (constants.k * T))
+    return 1.0 - add
+
+
 def raw_Gamma_diss(T: float, T1: float, vibr_one: float, Z_int: float, mass_molecule: float, mass_atom1: float,
                    mass_atom2: float, molecule_diss: float, n_molecule: float, n_atom1: float, n_atom2: float,
                    diss_level: int) -> float:
@@ -481,7 +806,7 @@ def raw_Gamma_diss(T: float, T1: float, vibr_one: float, Z_int: float, mass_mole
 def raw_Gamma_diss_oneT(T: float, Z_int: float, mass_molecule: float, mass_atom1: float, mass_atom2: float,
                         molecule_diss: float, n_molecule: float, n_atom1: float, n_atom2: float) -> float:
     """Calculates the generalized thermodynamic force :math:`\\Gamma^{diss}` for a dissociation reaction:
-    **AB(diss_level) + P -> A + B + P** in the one-temperature approximation, *raw* version
+    **AB + P -> A + B + P** in the one-temperature approximation, *raw* version
 
     Parameters
     ----------
