@@ -6,10 +6,32 @@ __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
 
-from .particles import Molecule, MoleculeSTS
+from .particles import MoleculeMultiT, Molecule, MoleculeOneT
 
 
-def wt_poly_norm(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float:
+def wt_poly_norm_sts(T: float, molecule: Molecule) -> float:
+    """Calculates the square of the "norm" of the Waldman Trubenbacher polynomial of the following form:
+    :math:`P_{j} = -[\\varepsilon_{j} / kT]'`, where :math:`j` is the rotational level of the molecule,
+    :math:`[A]' = A - <A>_{rot}`, where :math:`<>_{rot}`
+    denotes averaging over the rotational spectrum.
+    The square of the "norm" is defined as: :math:`||P_{j}||^{2} = \\left<P_{j}^{2} \\right>_{rot}`
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule : Molecule
+        the molecule for which the polynomial is calculated
+
+    Returns
+    -------
+    float
+        The square of the "norm" of the Waldman Trubenbacher polynomial used in the state-to-state approximation
+    """
+    return molecule.avg_rot_energy_sq(T, False) - (molecule.avg_rot_energy(T, False) ** 2)
+
+
+def wt_poly_norm_multiT(T: float, T1: float, molecule: MoleculeMultiT, F: float=0.0) -> float:
     """Calculates the square of the "norm" of the Waldman Trubenbacher polynomial of the following form:
     :math:`P_{ij} = -[\\varepsilon_{ij} / kT - i F]'`, where the :math:`i` is the vibrational level of the molecule,
     :math:`j` is the rotational level of the molecule, :math:`[A]' = A - <A>_{int}`, where :math:`<>_{int}`
@@ -22,7 +44,7 @@ def wt_poly_norm(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float
         the temperature of the mixture
     T1 : float
         the temperature of the first vibrational level of the molecule for which the polynomial is calculated
-    molecule : Molecule
+    molecule : MoleculeMultiT
         the molecule for which the polynomial is calculated
     F : float
         the constant appearing in the expression for the polynomial, defaults to ``0.0``
@@ -42,29 +64,33 @@ def wt_poly_norm(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float
                                                      - (wt_simple_avg(T, T1, molecule, F) ** 2)
 
 
-def wt_poly_norm_sts(T: float, molecule: MoleculeSTS) -> float:
+def wt_poly_norm_oneT(T: float, molecule: MoleculeOneT) -> float:
     """Calculates the square of the "norm" of the Waldman Trubenbacher polynomial of the following form:
-    :math:`P_{j} = -[\\varepsilon_{j} / kT]'`, where :math:`j` is the rotational level of the molecule,
-    :math:`[A]' = A - <A>_{rot}`, where :math:`<>_{rot}`
-    denotes averaging over the rotational spectrum.
-    The square of the "norm" is defined as: :math:`||P_{j}||^{2} = \\left<P_{j}^{2} \\right>_{rot}`
+    :math:`P_{ij} = -[\\varepsilon_{ij} / kT]'`, where the :math:`i` is the vibrational level of the molecule,
+    :math:`j` is the rotational level of the molecule, :math:`[A]' = A - <A>_{int}`, where :math:`<>_{int}`
+    denotes averaging over the internal spectrum.
+    The square of the "norm" is defined as: :math:`||P_{ij}||^{2} = \\left<P_{ij}^{2} \\right>_{int}`
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
-    molecule : MoleculeSTS or Molecule
+    molecule : MoleculeOneT
         the molecule for which the polynomial is calculated
+    F : float
+        the constant appearing in the expression for the polynomial, defaults to ``0.0``
 
     Returns
     -------
     float
-        The square of the "norm" of the Waldman Trubenbacher polynomial used in the state-to-state approximation
+        The square of the "norm" of the Waldman Trubenbacher polynomial
     """
-    return molecule.avg_rot_energy_sq(T, False) - (molecule.avg_rot_energy(T, False) ** 2)
+    return molecule.avg_vibr_energy_sq(T, False) + molecule.avg_rot_energy_sq(T, False)\
+                                                 + 2 * molecule.avg_vibr_energy(T, False)\
+                                                     * molecule.avg_rot_energy(T, False)
 
 
-def wt_simple_avg(T: float, T1: float, molecule: Molecule, F: float=0.0) -> float:
+def wt_simple_avg(T: float, T1: float, molecule: MoleculeMultiT, F: float=0.0) -> float:
     """Calculates the averaging over the internal energy spectrum of the following expression:
     :math:`\\varepsilon_{ij} / kT - i F`;
     that is, the quantity :math:`\\left<\\varepsilon_{ij} / kT - i F\\right>_{int}`
@@ -75,7 +101,7 @@ def wt_simple_avg(T: float, T1: float, molecule: Molecule, F: float=0.0) -> floa
         the temperature of the mixture
     T1 : float
         the temperature of the first vibrational level of the molecule for which the polynomial is calculated
-    molecule : Molecule
+    molecule : MoleculeMultiT
         the molecule for which the polynomial is calculated
     F : float
         the constant appearing in the expression for the polynomial, defaults to ``0.0``
